@@ -1057,8 +1057,8 @@ BasePlotCompositeWidget::filter(const QString filter_name,
   const ProcessingFlow &processing_flow =
     getProcessingFlowForPlottable(plottable_p);
 
-  qDebug() << "The source plottable:" << plottable_p;
-  qDebug() << "The processing flow:" << &processing_flow;
+  //qDebug() << "The source plottable:" << plottable_p;
+  //qDebug() << "The processing flow:" << &processing_flow;
 
   return processing_flow.filter(filter_name);
 }
