@@ -271,7 +271,7 @@ BaseTracePlotCompositeWidget::createMainMenu()
     if(!ok)
       qFatal("Failed to convert QVariant to double");
 
-    qDebug() << "triggered with threshold value:" << threshold;
+    //qDebug() << "triggered with threshold value:" << threshold;
 
     // Get the source plottable that might be of interest to the user.
     QCPAbstractPlottable *source_plottable_p =
