@@ -337,7 +337,7 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
 
   N = local_maxima_trace.size();
 
-  qDebug() << "The number of local maxima: " << N;
+  //qDebug() << "The number of local maxima: " << N;
 
   double *x     = new double[N];
   double *y     = new double[N];
@@ -615,13 +615,13 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
 
   delete[] a;
 
-  //qDebug() << "n has value:" << n;
+  // qDebug() << "n has value:" << n;
 
   for(int iter = 0; iter < n; ++iter)
     {
-      //qDebug() << "Iterating at iter:" << iter;
+      // qDebug() << "Iterating at iter:" << iter;
       delete[] B[iter];
-      //qDebug() << "deleted B at iter:" << iter;
+      // qDebug() << "deleted B at iter:" << iter;
     }
 
   // At this point, add the trace ! But only if it has points in it.
@@ -634,7 +634,7 @@ MassSpecTracePlotCompositeWidget::gaussianFitOnVisibleMaxima()
       m_ui.statusLineEdit->setText(
         "The Gaussian fit produced an empty trace. Plotting nothing.");
 
-        qDebug() << "The Gaussian fit produced an empty trace. Plotting nothing.";
+      //qDebug() << "The Gaussian fit produced an empty trace. Plotting nothing.";
 
       return;
     }
@@ -1169,7 +1169,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
           m_newTraceHandlingMethod == NewTraceHandlingMethod::PLUS_COMBINE)
 
     {
-      // qDebug();
+      //qDebug();
 
       // Combination is requested. There are some situations:
 
@@ -1181,9 +1181,16 @@ MassSpecTracePlotCompositeWidget::addTrace(
       // 3. If there are multiple traces, then only combine with those.
 
       if(!dest_plottable_list.size())
-        must_create_new_graph = true;
+        {
+          //qDebug() << "Adding trace but there is not a single trace available, "
+                      //"creating a new one.";
+
+          must_create_new_graph = true;
+        }
       else
         {
+          //qDebug() << "Adding new trace with combination requested.";
+
           // Since we are asked that an integration to a mass spectrum be
           // performed, there must be a non-nullptr mz integration pointer in
           // the step.
@@ -1196,10 +1203,13 @@ MassSpecTracePlotCompositeWidget::addTrace(
               "integration "
               "params are not available in the processing flow.");
 
+          //qDebug() << "The most recent mz integration parameters:"
+                   //<< mz_integration_params_p->toString();
+
           if(mz_integration_params_p->getBinningType() ==
              pappso::BinningType::NONE)
             {
-              // qDebug() << "Binning type none.";
+              //qDebug() << "Binning type none.";
 
               pappso::TraceMinusCombiner trace_minus_combiner;
               pappso::TracePlusCombiner trace_plus_combiner;
@@ -1401,7 +1411,8 @@ MassSpecTracePlotCompositeWidget::addTrace(
   // End of if(m_ui.keepTraceCombineNewPushButton->isChecked())
   else if(m_newTraceHandlingMethod == NewTraceHandlingMethod::REPLACE)
     {
-      // qDebug();
+      //qDebug() << "Adding new trace by the replace method: removing the "
+                  //"current one(s).";
 
       // Start by erasing all the traces that are selected.
 
@@ -1418,7 +1429,7 @@ MassSpecTracePlotCompositeWidget::addTrace(
     }
   else
     {
-      // qDebug();
+      //qDebug();
 
       // None of the button were checked, we simply created a new graph.
       must_create_new_graph = true;
@@ -1428,6 +1439,9 @@ MassSpecTracePlotCompositeWidget::addTrace(
     {
       // At this point we know we need to create a new trace.
 
+      //qDebug()
+        //<< "Adding a new trace: in fact we need to create one anew as is.";
+
       plottable_p = static_cast<pappso::BaseTracePlotWidget *>(mp_plotWidget)
                       ->addTrace(trace, local_color);
 
