@@ -185,7 +185,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrate()
 
   if(!mass_spectra_count)
     {
-      qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
+      //qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
 
       emit cancelOperationSignal();
     }
@@ -320,8 +320,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::integrateNoBinning()
   pappso::MzIntegrationParams local_mz_integration_params =
     m_processingFlow.getDefaultMzIntegrationParams();
 
-  qDebug().noquote() << "Starting integration with mz integration params:"
-                     << local_mz_integration_params.toString();
+  //qDebug().noquote() << "Starting integration with mz integration params:"
+                     //<< local_mz_integration_params.toString();
 
   // Instanciate a plus combiner that will be used as a template for all the
   // combiners operating concurrently below. Note that because we do not make
@@ -792,8 +792,8 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
   pappso::MzIntegrationParams local_mz_integration_params =
     m_processingFlow.getDefaultMzIntegrationParams();
 
-  qDebug().noquote() << "Starting integration with mz integration params:"
-                     << local_mz_integration_params.toString();
+  //qDebug().noquote() << "Starting integration with mz integration params:"
+                     //<< local_mz_integration_params.toString();
 
   // Instanciate a plus combiner that will be used as a template for all the
   // combiners operating concurrently below. Note that because we are computing
@@ -821,12 +821,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToDtRtMz::
         mcsp_msRunDataSet->getMsRunDataSetStats().m_maxMz);
     }
 
-  qDebug() << "Now starting creation of the bins.";
+  //qDebug() << "Now starting creation of the bins.";
 
   // Now we can create the bins!
   std::vector<double> bins = local_mz_integration_params.createBins();
 
-  qDebug() << "Number of bins: " << bins.size();
+  //qDebug() << "Number of bins: " << bins.size();
 
   template_plus_combiner.setBins(bins);
 
