@@ -148,7 +148,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrate()
 bool
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 {
-  qDebug();
+  //qDebug();
 
   // If there are no data, nothing to do.
   std::size_t mass_spectra_count =
@@ -156,12 +156,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 
   if(!mass_spectra_count)
     {
-      qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
+      //qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
 
       emit cancelOperationSignal();
     }
 
-  qDebug() << "The number of mass spectra to handle:" << mass_spectra_count;
+  //qDebug() << "The number of mass spectra to handle:" << mass_spectra_count;
 
   emit setTaskDescriptionTextSignal(
     "Integrating to a mass spectrum (no binning)");
@@ -191,16 +191,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // at combination time, because that is precisely the only moment that we can
   // do that work.
 
-  qDebug() << "Now filling-in the selectionpolygonspecs.";
+  //qDebug() << "Now filling-in the selectionpolygonspecs.";
 
   std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
 
-  std::size_t selection_polygon_spec_count =
+  //std::size_t selection_polygon_spec_count =
     fillInSelectionPolygonSpecs(selection_polygon_specs);
 
-  qDebug() << selection_polygon_spec_count
-           << "selection polygon specs were retained for the configuration of "
-              "the filter.";
+  //qDebug() << selection_polygon_spec_count
+           //<< "selection polygon specs were retained for the configuration of "
+              //"the filter.";
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -243,7 +243,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // template_plus_combiner.addFilter(filter_csp);
   //}
 
-  qDebug();
+  //qDebug();
 
   // At this point, allocate a visitor that is specific for the calculation of
   // the mass spectrum. Since we are not binning, we can use a visitor that
@@ -282,7 +282,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
   // Now that we have all the parallel material, we can start the parallel work.
   emit setProgressBarMaxValueSignal(mass_spectra_count);
 
-  qDebug() << "Starting the iteration in the visitors.";
+  //qDebug() << "Starting the iteration in the visitors.";
 
   omp_set_num_threads(iterators.size());
 #pragma omp parallel for ordered
@@ -351,13 +351,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 
           if(!checkMsLevel(qualified_mass_spectrum_csp))
             {
-              qDebug() << "The MsLevel check returned false";
+              //qDebug() << "The MsLevel check returned false";
               ++current_iterator;
               continue;
             }
           if(!checkMsFragmentation(qualified_mass_spectrum_csp))
             {
-              qDebug() << "The MsFragmentation check returned false";
+              //qDebug() << "The MsFragmentation check returned false";
               ++current_iterator;
               continue;
             }
@@ -366,15 +366,13 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::integrateToMzNoBinning()
 
           if(!checkRtRange(qualified_mass_spectrum_csp))
             {
-              qDebug() << "checkRtRange failed check.";
-
+              //qDebug() << "checkRtRange failed check.";
               ++current_iterator;
               continue;
             }
           if(!checkDtRange(qualified_mass_spectrum_csp))
             {
-              qDebug() << "checkDtRange failed check.";
-
+              //qDebug() << "checkDtRange failed check.";
               ++current_iterator;
               continue;
             }
@@ -507,7 +505,7 @@ bool
 QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   integrateToMzArbitraryBinning()
 {
-  qDebug();
+  //qDebug();
 
   // If there are no data, nothing to do.
   std::size_t mass_spectra_count =
@@ -515,12 +513,12 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
   if(!mass_spectra_count)
     {
-      qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
+      //qDebug() << "The qualified mass spectrum vector is empty, nothing to do.";
 
       emit cancelOperationSignal();
     }
 
-  qDebug() << "The number of mass spectra to handle:" << mass_spectra_count;
+  //qDebug() << "The number of mass spectra to handle:" << mass_spectra_count;
 
   emit setTaskDescriptionTextSignal("Integrating to a mass spectrum (binning)");
 
@@ -541,7 +539,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
   if(!local_mz_integration_params.isValid())
     {
-      qDebug() << "The mz integration params are not valid.";
+     //qDebug() << "The mz integration params are not valid.";
 
       // If the mz integration params are not valid, then we cannot know the
       // start and end of the bins ! We need to resort to the statistical data
@@ -554,26 +552,20 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
         mcsp_msRunDataSet->getMsRunDataSetStats().m_maxMz);
     }
 
-  // qDebug().noquote() << "Starting integration with mz integration params:"
-  //<< local_mz_integration_params.toString();
+  //qDebug().noquote() << "Starting integration with mz integration params:"
+                     //<< local_mz_integration_params.toString();
 
   // Now we can create the bins!
   std::vector<double> bins = local_mz_integration_params.createBins();
 
-#if 0
+  #if 0
   QString bins_before = "Bins:\n";
   for(auto &&bin : bins)
     bins_before += QString("%1\n").arg(bin, 0, 'f', 6);
 
-    // qDebug() << "Created bins at:"
-    //<< QDateTime::currentDateTime().toString("yyyyMMdd-HH-mm-ss");
-
-#endif
-
-
-#if 0
-  QString fileName = "/tmp/massSpecArbitraryBins.txt-at-" +
-                     QDateTime::currentDateTime().toString("yyyyMMdd-HH-mm-ss");
+  QString date_time =
+    QDateTime::currentDateTime().toString("yyyyMMdd-HH-mm-ss");
+  QString fileName = "/tmp/massSpecArbitraryBins.txt-at-" + date_time;
 
   qDebug() << "Writing the list of bins setup in the "
               "mass spectrum in file "
@@ -589,7 +581,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
 
   fileStream.flush();
   file.close();
-#endif
+  #endif
 
 
   // When constructing this integrator, the processing flow passed as parameter
@@ -611,16 +603,16 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // at combination time, because that is precisely the only moment that we can
   // do that work.
 
-  qDebug() << "Now filling-in the selectionpolygonspecs.";
+  //qDebug() << "Now filling-in the selectionpolygonspecs.";
 
   std::vector<pappso::SelectionPolygonSpec> selection_polygon_specs;
 
-  std::size_t selection_polygon_spec_count =
+  //std::size_t selection_polygon_spec_count =
     fillInSelectionPolygonSpecs(selection_polygon_specs);
 
-  qDebug() << selection_polygon_spec_count
-           << "selection polygon specs were retained for the configuration of "
-              "the filter.";
+  //qDebug() << selection_polygon_spec_count
+           //<< "selection polygon specs were retained for the configuration of "
+              //"the filter.";
 
   // Prepare the template for all the combiners we'll use in the different
   // threads.
@@ -680,7 +672,7 @@ QualifiedMassSpectrumVectorMassDataIntegratorToMz::
   // Now that we have all the parallel material, we can start the parallel work.
   emit setProgressBarMaxValueSignal(mass_spectra_count);
 
-  qDebug() << "Starting the iteration in the visitors.";
+  //qDebug() << "Starting the iteration in the visitors.";
 
   omp_set_num_threads(iterators.size());
 #pragma omp parallel for ordered
